==> contentsquare-1.0.1.tar.gz: test/src/modules/screengraph/render_object_extension_test.dart <==
import 'package:contentsquare/src/modules/screengraph/painted_render_object_tree.dart';
import 'package:contentsquare/src/modules/screengraph/render_object_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_test/flutter_test.dart';

class CustomRenderObject extends RenderObject {
  @override
  void debugAssertDoesMeetConstraints() {}

  @override
  Rect get paintBounds => throw UnimplementedError();

  @override
  void performResize() {}

  @override
  Rect get semanticBounds => throw UnimplementedError();

  @override
  void performLayout() {}
}

main() {
  group(
    'frames',
    () {
      group(
        'RenderView',
        () {
          testWidgets(
            'Should return the frame with the right size/offset in the global coordinate system and in the local coordinate system',
            (WidgetTester tester) async {
              await tester.pumpWidget(
                const MaterialApp(
                  home: Scaffold(
                    body: Center(
                      child: Text('Hello'),
                    ),
                  ),
                ),
              );

              final screenSize = tester.binding.renderView.size;
              final renderObject = getRootRenderObject();

              expect(renderObject, isA<RenderView>());

              // The global frame should fill the entire screen.
              expect(
                renderObject.globalFrame,
                Rect.fromLTWH(0, 0, screenSize.width, screenSize.height),
              );

              // The local frame should fill the entire screen.
              expect(
                renderObject.localFrame,
                Rect.fromLTWH(0, 0, screenSize.width, screenSize.height),
              );
            },
          );
        },
      );

      group(
        'RenderBox',
        () {
          testWidgets(
            'Should return different frame with the right size/offset in the global coordinate system vs in the local coordinate system',
            (WidgetTester tester) async {
              const _outerFrame = Rect.fromLTWH(10, 10, 100, 100);
              const _innerFrame = Rect.fromLTWH(20, 20, 50, 50);
              await tester.pumpWidget(
                MaterialApp(
                  home: Scaffold(
                    body: Stack(
                      fit: StackFit.expand,
                      children: [
                        Positioned.fromRect(
                          rect: _outerFrame,
                          child: Stack(
                            fit: StackFit.expand,
                            children: [
                              Positioned.fromRect(
                                rect: _innerFrame,
                                child: const Center(
                                  child: Text('Hello World'),
                                ),
                              ),
                            ],
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              );

              final renderObject = tester.renderObject(find.byType(Center));

              expect(renderObject, isA<RenderBox>());

              // The global frame should be shifted by the outer frame.
              expect(
                renderObject.globalFrame,
                _innerFrame.shift(_outerFrame.topLeft),
              );

              // The local frame should be the same size as the inner frame but without
              // any offset.
              expect(
                renderObject.localFrame,
                Rect.fromLTWH(0, 0, _innerFrame.width, _innerFrame.height),
              );
            },
          );
        },
      );

      group(
        'RenderSliver',
        () {
          testWidgets(
            'Should return different frame with the right size/offset in the global coordinate system vs in the local coordinate system',
            (WidgetTester tester) async {
              const _outerFrame = Rect.fromLTWH(10, 10, 100, 100);
              const _innerFrame = Rect.fromLTWH(20, 20, 50, 50);
              await tester.pumpWidget(
                MaterialApp(
                  home: Scaffold(
                    body: Stack(
                      fit: StackFit.expand,
                      children: [
                        Positioned.fromRect(
                          rect: _outerFrame,
                          child: Stack(
                            fit: StackFit.expand,
                            children: [
                              Positioned.fromRect(
                                rect: _innerFrame,
                                child: ListView(
                                  shrinkWrap: true,
                                  children: const [Text('Hello World')],
                                ),
                              ),
                            ],
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              );

              final renderObject = tester.renderObject(find.byType(SliverList));

              expect(renderObject, isA<RenderSliver>());

              // The global frame should be shifted by the outer frame.
              expect(
                renderObject.globalFrame,
                _innerFrame.shift(_outerFrame.topLeft),
              );

              // The local frame should be the same size as the inner frame but without
              // any offset.
              expect(
                renderObject.localFrame,
                Rect.fromLTWH(0, 0, _innerFrame.width, _innerFrame.height),
              );
            },
          );
        },
      );

      testWidgets(
        'Should return null when the render object is not supported',
        (WidgetTester tester) async {
          expect(CustomRenderObject().globalFrame, null);
          expect(CustomRenderObject().localFrame, null);
        },
      );
    },
  );
}

==> contentsquare-2.0.0.tar.gz: test/src/modules/screengraph/render_object_extension_test.dart <==
import 'package:contentsquare/src/modules/screengraph/painted_render_object_tree.dart';
import 'package:contentsquare/src/modules/screengraph/render_object_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_test/flutter_test.dart';

class CustomRenderObject extends RenderObject {
  @override
  void debugAssertDoesMeetConstraints() {}

  @override
  Rect get paintBounds => throw UnimplementedError();

  @override
  void performResize() {}

  @override
  Rect get semanticBounds => throw UnimplementedError();

  @override
  void performLayout() {}
}

main() {
  group(
    'frames',
    () {
      group(
        'RenderView',
        () {
          testWidgets(
            'Should return the frame with the right size/offset in the global coordinate system and in the local coordinate system',
            (WidgetTester tester) async {
              await tester.pumpWidget(
                const MaterialApp(
                  home: Scaffold(
                    body: Center(
                      child: Text('Hello'),
                    ),
                  ),
                ),
              );

              final screenSize = tester.binding.renderView.size;
              final renderObject = getRootRenderObject();

              expect(renderObject, isA<RenderView>());

              // The global frame should fill the entire screen.
              expect(
                renderObject.globalFrame,
                Rect.fromLTWH(0, 0, screenSize.width, screenSize.height),
              );

              // The local frame should fill the entire screen.
              expect(
                renderObject.localFrame,
                Rect.fromLTWH(0, 0, screenSize.width, screenSize.height),
              );
            },
          );
        },
      );

      group(
        'RenderBox',
        () {
          testWidgets(
            'Should return different frame with the right size/offset in the global coordinate system vs in the local coordinate system',
            (WidgetTester tester) async {
              const _outerFrame = Rect.fromLTWH(10, 10, 100, 100);
              const _innerFrame = Rect.fromLTWH(20, 20, 50, 50);
              await tester.pumpWidget(
                MaterialApp(
                  home: Scaffold(
                    body: Stack(
                      fit: StackFit.expand,
                      children: [
                        Positioned.fromRect(
                          rect: _outerFrame,
                          child: Stack(
                            fit: StackFit.expand,
                            children: [
                              Positioned.fromRect(
                                rect: _innerFrame,
                                child: const Center(
                                  child: Text('Hello World'),
                                ),
                              ),
                            ],
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              );

              final renderObject = tester.renderObject(find.byType(Center));

              expect(renderObject, isA<RenderBox>());

              // The global frame should be shifted by the outer frame.
              expect(
                renderObject.globalFrame,
                _innerFrame.shift(_outerFrame.topLeft),
              );

              // The local frame should be the same size as the inner frame but
              // without any offset.
              expect(
                renderObject.localFrame,
                Rect.fromLTWH(0, 0, _innerFrame.width, _innerFrame.height),
              );
            },
          );
        },
      );

      group(
        'RenderSliver',
        () {
          testWidgets(
            'Should return different frame with the right size/offset in the global coordinate system vs in the local coordinate system',
            (WidgetTester tester) async {
              const _outerFrame = Rect.fromLTWH(10, 10, 100, 100);
              const _innerFrame = Rect.fromLTWH(20, 20, 50, 50);
              await tester.pumpWidget(
                MaterialApp(
                  home: Scaffold(
                    body: Stack(
                      fit: StackFit.expand,
                      children: [
                        Positioned.fromRect(
                          rect: _outerFrame,
                          child: Stack(
                            fit: StackFit.expand,
                            children: [
                              Positioned.fromRect(
                                rect: _innerFrame,
                                child: ListView(
                                  shrinkWrap: true,
                                  children: const [Text('Hello World')],
                                ),
                              ),
                            ],
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              );

              final renderObject = tester.renderObject(find.byType(SliverList));

              expect(renderObject, isA<RenderSliver>());

              // The global frame should be shifted by the outer frame.
              expect(
                renderObject.globalFrame,
                _innerFrame.shift(_outerFrame.topLeft),
              );

              // The local frame should be the same size as the inner frame but
              // without any offset.
              expect(
                renderObject.localFrame,
                Rect.fromLTWH(0, 0, _innerFrame.width, _innerFrame.height),
              );
            },
          );
        },
      );

      testWidgets(
        'Should return null when the render object is not supported',
        (WidgetTester tester) async {
          expect(CustomRenderObject().globalFrame, null);
          expect(CustomRenderObject().localFrame, null);
        },
      );
    },
  );
}
